@@ -102,13 +102,15 @@ class WykopAPI:
         return self.request('Entries', 'Comment',
                             api_params=self.__api_param(comment_id))
 
-    def entry_comment_add(self, entry_id: str, body: str, file=None, file_url: str = None, is_adult_media: bool = False):
+    def entry_comment_add(self, entry_id: str, body: str, file=None, file_url: str = None,
+                          is_adult_media: bool = False):
         return self.request('Entries', 'CommentAdd',
                             post_params=self.content_post_params(body, file_url, is_adult_media),
                             api_params=self.__api_param(entry_id),
                             file_params=self.__with_file(file))
 
-    def entry_comment_edit(self, comment_id: str, body: str, file=None, file_url: str = None, is_adult_media: bool = False):
+    def entry_comment_edit(self, comment_id: str, body: str, file=None, file_url: str = None,
+                           is_adult_media: bool = False):
         return self.request('Entries', 'CommentEdit',
                             post_params=self.content_post_params(body, file_url, is_adult_media),
                             api_params=self.__api_param(comment_id),
@@ -193,42 +195,83 @@ class WykopAPI:
 
     # notifications
 
-    def direct_notifications(self, page=1):
+    def notifications_direct(self, page=1):
         return self.request('notifications',
                             named_params=self.__with_page(page))
 
-    def direct_notifications_count(self):
+    def notifications_direct_count(self):
         return self.request('notifications', 'Count')
 
-    def hashtags_notifications(self, page=1):
+    def notifications_hashtags_notifications(self, page=1):
         return self.request('notifications', 'hashtags',
                             named_params=self.__with_page(page))
 
-    def hashtags_notifications_count(self):
+    def notifications_hashtags_count(self):
         return self.request('notifications', 'hashtagscount')
 
-    def all_notifications(self, page=1):
+    def notifications_all(self, page=1):
         return self.request('notifications', 'total',
                             named_params=self.__with_page(page))
 
-    def all_notifications_count(self):
+    def notifications_all_count(self):
         return self.request('notifications', 'totalcount')
 
-    def mark_all_notification_as_read(self):
+    def notification_mark_all_as_read(self):
         return self.request('Notifications', 'ReadAllNotifications')
 
-    def mark_all_direct_notification_as_read(self):
+    def notifications_mark_all_direct_as_read(self):
         return self.request('Notifications', 'ReadDirectedNotifications')
 
-    def mark_all_hashtag_notification_as_read(self):
+    def notifications_mark_all_hashtag_as_read(self):
         return self.request('Notifications', 'ReadHashTagsNotifications')
 
-    def mark_notification_as_read(self, notification_id):
+    def notification_mark_as_read(self, notification_id):
         return self.request('Notifications', 'MarkAsRead',
                             api_params=self.__api_param(notification_id))
 
     # search
 
+    def search_links(self, page=1, query=None, when=None, votes=None, from_date=None, to_date=None, what=None,
+                     sort=None):
+        assert len(query) > 2 if query else True
+        assert when in ["all", "today", "yesterday", "week", "month", "range"] if when else True
+        assert what in ["all", "promoted", "archived", "duplicates"] if when else True
+        assert sort in ["best", "diggs", "comments", "new"] if when else True
+        post_params = {
+            'q': query,
+            'when': when,
+            'votes': votes,
+            'from': from_date,
+            'to': to_date,
+            'what': what,
+            'sort': sort
+        }
+        return self.request('Search', 'Links',
+                            post_params=post_params,
+                            named_params=self.__with_page(page))
+
+    def search_entries(self, page=1, query=None, when=None, votes=None, from_date=None, to_date=None):
+        assert len(query) > 2 if query else True
+        assert when in ["all", "today", "yesterday", "week", "month", "range"] if when else True
+        post_params = {
+            'q': query,
+            'when': when,
+            'votes': votes,
+            'from': from_date,
+            'to': to_date
+        }
+        return self.request('Search', 'Entries',
+                            post_params=post_params,
+                            named_params=self.__with_page(page))
+
+    def search_profiles(self, query):
+        assert len(query) > 2 if query else True
+        post_params = {
+            'q': query,
+        }
+        return self.request('Search', 'Profiles',
+                            post_params=post_params)
+
     # tags
 
     def tag(self, tag, page=1):
